@@ -29,11 +29,11 @@
 #include <tqpixmap.h>
 #include <tqwhatsthis.h>
 #include <tqstringlist.h>
-#include <klocale.h>
-#include <kfiledialog.h>
+#include <tdelocale.h>
+#include <tdefiledialog.h>
 #include <kiconloader.h>
-#include <ktempfile.h>
-#include <kmessagebox.h>
+#include <tdetempfile.h>
+#include <tdemessagebox.h>
 #include <kstandarddirs.h>
 #include "kiledebug.h"
 
@@ -84,8 +84,8 @@ PostscriptDialog::PostscriptDialog(TQWidget *parent,
 	grid->setColStretch(1,1);
 
 	// line 0: TQLabel
-	bool pstops = ! KStandardDirs::findExe("pstops").isNull();
-	bool psselect = ! KStandardDirs::findExe("psselect").isNull();
+	bool pstops = ! TDEStandardDirs::findExe("pstops").isNull();
+	bool psselect = ! TDEStandardDirs::findExe("psselect").isNull();
 
 	TQString title = i18n("Conversion of ps files is made by 'pstops' and 'psselect'.\nBe sure to call 'dvips' with option '-t a4' and\nhyperref package (if needed) with option 'a4paper'.");
 
@@ -121,7 +121,7 @@ PostscriptDialog::PostscriptDialog(TQWidget *parent,
 
 	// line 1: Choose-Box
 	TQPushButton *choose_in = new TQPushButton("", widget, "infilechooser" );
-	choose_in->setPixmap( SmallIcon("fileopen") );
+	choose_in->setPixmap( SmallIcon("document-open") );
 	choose_in->setFixedWidth(choose_in->sizeHint().width());        
 	grid->addWidget(choose_in,2,2);
 
@@ -136,7 +136,7 @@ PostscriptDialog::PostscriptDialog(TQWidget *parent,
 
 	// line 3: choose box
 	TQPushButton *choose_out = new TQPushButton("", widget, "outfilechooser" );
-	choose_out->setPixmap( SmallIcon("fileopen") );
+	choose_out->setPixmap( SmallIcon("document-open") );
 	choose_out->setFixedWidth(choose_out->sizeHint().width());  
 	grid->addWidget(choose_out,3,2);
 
@@ -275,29 +275,29 @@ void PostscriptDialog::execute()
 		m_proc->clearArguments(); 
 		(*m_proc) << TQStringList::split(' ',"sh " + m_tempfile);
 		   
-		connect(m_proc, TQT_SIGNAL(receivedStdout(KProcess *,char *,int)), 
-		        this, TQT_SLOT(slotProcessOutput(KProcess *,char *,int)));
-		connect(m_proc, TQT_SIGNAL(receivedStderr(KProcess*,char*,int)),
-		        this, TQT_SLOT(slotProcessOutput(KProcess*,char*,int)) );
-		connect(m_proc, TQT_SIGNAL(processExited(KProcess *)), 
-		        this, TQT_SLOT(slotProcessExited(KProcess *)));
+		connect(m_proc, TQT_SIGNAL(receivedStdout(TDEProcess *,char *,int)), 
+		        this, TQT_SLOT(slotProcessOutput(TDEProcess *,char *,int)));
+		connect(m_proc, TQT_SIGNAL(receivedStderr(TDEProcess*,char*,int)),
+		        this, TQT_SLOT(slotProcessOutput(TDEProcess*,char*,int)) );
+		connect(m_proc, TQT_SIGNAL(processExited(TDEProcess *)), 
+		        this, TQT_SLOT(slotProcessExited(TDEProcess *)));
 
 		KILE_DEBUG() << "=== PostscriptDialog::runPsutils() ====================" << endl;
 		KILE_DEBUG() << "   execute '" << m_tempfile << "'" << endl;
-		//if ( ! proc->start(KProcess::NotifyOnExit, KProcess::NoCommunication) ) 
-		if ( ! m_proc->start(KProcess::NotifyOnExit, KProcess::AllOutput) ) 
+		//if ( ! proc->start(TDEProcess::NotifyOnExit, TDEProcess::NoCommunication) ) 
+		if ( ! m_proc->start(TDEProcess::NotifyOnExit, TDEProcess::AllOutput) ) 
 			KILE_DEBUG() << "\tstart of shell process failed" << endl;
 	}
 	
 }
 
-void PostscriptDialog::slotProcessOutput(KProcess*,char* buf,int len)
+void PostscriptDialog::slotProcessOutput(TDEProcess*,char* buf,int len)
 {
 	emit( output(TQCString(buf,len+1)) );
 }
 
 
-void PostscriptDialog::slotProcessExited (KProcess *proc)
+void PostscriptDialog::slotProcessExited (TDEProcess *proc)
 {
 	if ( ! proc->normalExit() ) 
 		showError(i18n("An error occurred, while rearranging the file."));
